Class: Aws::Route53::Types::GetAccountLimitResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::GetAccountLimitResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A complex type that contains the requested limit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The current number of entities that you have created of the specified type.
-
#limit ⇒ Types::AccountLimit
The current setting for the specified limit.
Instance Attribute Details
#count ⇒ Integer
The current number of entities that you have created of the specified type. For example, if you specified MAX_HEALTH_CHECKS_BY_OWNER for the value of Type in the request, the value of Count is the current number of health checks that you have created using the current account.
2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-route53/types.rb', line 2584 class GetAccountLimitResponse < Struct.new( :limit, :count) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Types::AccountLimit
The current setting for the specified limit. For example, if you specified MAX_HEALTH_CHECKS_BY_OWNER for the value of Type in the request, the value of Limit is the maximum number of health checks that you can create using the current account.
2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-route53/types.rb', line 2584 class GetAccountLimitResponse < Struct.new( :limit, :count) SENSITIVE = [] include Aws::Structure end |