Class: Aws::Route53::Types::GetChangeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53/types.rb

Overview

The input for a GetChange request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID of the change batch request. The value that you specify here is the value that ChangeResourceRecordSets returned in the Id element when you submitted the request.



2601
2602
2603
2604
2605
# File 'lib/aws-sdk-route53/types.rb', line 2601

class GetChangeRequest < Struct.new(
  :id)
  SENSITIVE = []
  include Aws::Structure
end