Class: Aws::Route53::Types::HostedZone
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::HostedZone
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A complex type that contains general information about the hosted zone.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#caller_reference ⇒ String
The value that you specified for ‘CallerReference` when you created the hosted zone.
-
#config ⇒ Types::HostedZoneConfig
A complex type that includes the ‘Comment` and `PrivateZone` elements.
-
#features ⇒ Types::HostedZoneFeatures
The features configuration for the hosted zone, including accelerated recovery settings and status information.
-
#id ⇒ String
The ID that Amazon Route 53 assigned to the hosted zone when you created it.
-
#linked_service ⇒ Types::LinkedService
If the hosted zone was created by another service, the service that created the hosted zone.
-
#name ⇒ String
The name of the domain.
-
#resource_record_set_count ⇒ Integer
The number of resource record sets in the hosted zone.
Instance Attribute Details
#caller_reference ⇒ String
The value that you specified for ‘CallerReference` when you created the hosted zone.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#config ⇒ Types::HostedZoneConfig
A complex type that includes the ‘Comment` and `PrivateZone` elements. If you omitted the `HostedZoneConfig` and `Comment` elements from the request, the `Config` and `Comment` elements don’t appear in the response.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#features ⇒ Types::HostedZoneFeatures
The features configuration for the hosted zone, including accelerated recovery settings and status information.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID that Amazon Route 53 assigned to the hosted zone when you created it.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#linked_service ⇒ Types::LinkedService
If the hosted zone was created by another service, the service that created the hosted zone. When a hosted zone is created by another service, you can’t edit or delete it using Route 53.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the domain. For public hosted zones, this is the name that you have registered with your DNS registrar.
For information about how to specify characters other than ‘a-z`, `0-9`, and `-` (hyphen) and how to specify internationalized domain names, see [CreateHostedZone].
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHostedZone.html
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |
#resource_record_set_count ⇒ Integer
The number of resource record sets in the hosted zone.
3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 |
# File 'lib/aws-sdk-route53/types.rb', line 3795 class HostedZone < Struct.new( :id, :name, :caller_reference, :config, :resource_record_set_count, :linked_service, :features) SENSITIVE = [] include Aws::Structure end |