Class: Aws::Route53::Types::ListCidrLocationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListCidrLocationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collection_id ⇒ String
The CIDR collection ID.
-
#max_results ⇒ String
The maximum number of CIDR collection locations to return in the response.
-
#next_token ⇒ String
An opaque pagination token to indicate where the service is to begin enumerating results.
Instance Attribute Details
#collection_id ⇒ String
The CIDR collection ID.
4657 4658 4659 4660 4661 4662 4663 |
# File 'lib/aws-sdk-route53/types.rb', line 4657 class ListCidrLocationsRequest < Struct.new( :collection_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ String
The maximum number of CIDR collection locations to return in the response.
4657 4658 4659 4660 4661 4662 4663 |
# File 'lib/aws-sdk-route53/types.rb', line 4657 class ListCidrLocationsRequest < Struct.new( :collection_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An opaque pagination token to indicate where the service is to begin enumerating results.
If no value is provided, the listing of results starts from the beginning.
4657 4658 4659 4660 4661 4662 4663 |
# File 'lib/aws-sdk-route53/types.rb', line 4657 class ListCidrLocationsRequest < Struct.new( :collection_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |