Class: Aws::Route53::Types::ListGeoLocationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListGeoLocationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A request to get a list of geographic locations that Amazon Route 53 supports for geolocation resource record sets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_items ⇒ Integer
(Optional) The maximum number of geolocations to be included in the response body for this request.
-
#start_continent_code ⇒ String
The code for the continent with which you want to start listing locations that Amazon Route 53 supports for geolocation.
-
#start_country_code ⇒ String
The code for the country with which you want to start listing locations that Amazon Route 53 supports for geolocation.
-
#start_subdivision_code ⇒ String
The code for the state of the United States with which you want to start listing locations that Amazon Route 53 supports for geolocation.
Instance Attribute Details
#max_items ⇒ Integer
(Optional) The maximum number of geolocations to be included in the response body for this request. If more than maxitems geolocations remain to be listed, then the value of the IsTruncated element in the response is true.
4733 4734 4735 4736 4737 4738 4739 4740 |
# File 'lib/aws-sdk-route53/types.rb', line 4733 class ListGeoLocationsRequest < Struct.new( :start_continent_code, :start_country_code, :start_subdivision_code, :max_items) SENSITIVE = [] include Aws::Structure end |
#start_continent_code ⇒ String
The code for the continent with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextContinentCode from the previous response has a value, enter that value in startcontinentcode to return the next page of results.
Include startcontinentcode only if you want to list continents. Don’t include startcontinentcode when you’re listing countries or countries with their subdivisions.
4733 4734 4735 4736 4737 4738 4739 4740 |
# File 'lib/aws-sdk-route53/types.rb', line 4733 class ListGeoLocationsRequest < Struct.new( :start_continent_code, :start_country_code, :start_subdivision_code, :max_items) SENSITIVE = [] include Aws::Structure end |
#start_country_code ⇒ String
The code for the country with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextCountryCode from the previous response has a value, enter that value in startcountrycode to return the next page of results.
4733 4734 4735 4736 4737 4738 4739 4740 |
# File 'lib/aws-sdk-route53/types.rb', line 4733 class ListGeoLocationsRequest < Struct.new( :start_continent_code, :start_country_code, :start_subdivision_code, :max_items) SENSITIVE = [] include Aws::Structure end |
#start_subdivision_code ⇒ String
The code for the state of the United States with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextSubdivisionCode from the previous response has a value, enter that value in startsubdivisioncode to return the next page of results.
To list subdivisions (U.S. states), you must include both startcountrycode and startsubdivisioncode.
4733 4734 4735 4736 4737 4738 4739 4740 |
# File 'lib/aws-sdk-route53/types.rb', line 4733 class ListGeoLocationsRequest < Struct.new( :start_continent_code, :start_country_code, :start_subdivision_code, :max_items) SENSITIVE = [] include Aws::Structure end |