Class: Aws::Route53::Types::ListHealthChecksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListHealthChecksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A complex type that contains the response to a ListHealthChecks request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#health_checks ⇒ Array<Types::HealthCheck>
A complex type that contains one
HealthCheckelement for each health check that is associated with the current Amazon Web Services account. -
#is_truncated ⇒ Boolean
A flag that indicates whether there are more health checks to be listed.
-
#marker ⇒ String
For the second and subsequent calls to
ListHealthChecks,Markeris the value that you specified for themarkerparameter in the previous request. -
#max_items ⇒ Integer
The value that you specified for the
maxitemsparameter in the call toListHealthChecksthat produced the current response. -
#next_marker ⇒ String
If
IsTruncatedistrue, the value ofNextMarkeridentifies the first health check that Amazon Route 53 returns if you submit anotherListHealthChecksrequest and specify the value ofNextMarkerin themarkerparameter.
Instance Attribute Details
#health_checks ⇒ Array<Types::HealthCheck>
A complex type that contains one HealthCheck element for each health check that is associated with the current Amazon Web Services account.
4864 4865 4866 4867 4868 4869 4870 4871 4872 |
# File 'lib/aws-sdk-route53/types.rb', line 4864 class ListHealthChecksResponse < Struct.new( :health_checks, :marker, :is_truncated, :next_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more health checks to be listed. If the response was truncated, you can get the next group of health checks by submitting another ListHealthChecks request and specifying the value of NextMarker in the marker parameter.
4864 4865 4866 4867 4868 4869 4870 4871 4872 |
# File 'lib/aws-sdk-route53/types.rb', line 4864 class ListHealthChecksResponse < Struct.new( :health_checks, :marker, :is_truncated, :next_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
For the second and subsequent calls to ListHealthChecks, Marker is the value that you specified for the marker parameter in the previous request.
4864 4865 4866 4867 4868 4869 4870 4871 4872 |
# File 'lib/aws-sdk-route53/types.rb', line 4864 class ListHealthChecksResponse < Struct.new( :health_checks, :marker, :is_truncated, :next_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The value that you specified for the maxitems parameter in the call to ListHealthChecks that produced the current response.
4864 4865 4866 4867 4868 4869 4870 4871 4872 |
# File 'lib/aws-sdk-route53/types.rb', line 4864 class ListHealthChecksResponse < Struct.new( :health_checks, :marker, :is_truncated, :next_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If IsTruncated is true, the value of NextMarker identifies the first health check that Amazon Route 53 returns if you submit another ListHealthChecks request and specify the value of NextMarker in the marker parameter.
4864 4865 4866 4867 4868 4869 4870 4871 4872 |
# File 'lib/aws-sdk-route53/types.rb', line 4864 class ListHealthChecksResponse < Struct.new( :health_checks, :marker, :is_truncated, :next_marker, :max_items) SENSITIVE = [] include Aws::Structure end |