Class: Aws::Route53::Types::ListTrafficPoliciesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53/types.rb

Overview

A complex type that contains the response information for the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether there are more traffic policies to be listed. If the response was truncated, you can get the next group of traffic policies by submitting another ListTrafficPolicies request and specifying the value of TrafficPolicyIdMarker in the TrafficPolicyIdMarker request parameter.

Returns:



5584
5585
5586
5587
5588
5589
5590
5591
# File 'lib/aws-sdk-route53/types.rb', line 5584

class ListTrafficPoliciesResponse < Struct.new(
  :traffic_policy_summaries,
  :is_truncated,
  :traffic_policy_id_marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The value that you specified for the MaxItems parameter in the ListTrafficPolicies request that produced the current response.

Returns:



5584
5585
5586
5587
5588
5589
5590
5591
# File 'lib/aws-sdk-route53/types.rb', line 5584

class ListTrafficPoliciesResponse < Struct.new(
  :traffic_policy_summaries,
  :is_truncated,
  :traffic_policy_id_marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_policy_id_markerString

If the value of IsTruncated is true, TrafficPolicyIdMarker is the ID of the first traffic policy in the next group of MaxItems traffic policies.

Returns:



5584
5585
5586
5587
5588
5589
5590
5591
# File 'lib/aws-sdk-route53/types.rb', line 5584

class ListTrafficPoliciesResponse < Struct.new(
  :traffic_policy_summaries,
  :is_truncated,
  :traffic_policy_id_marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_policy_summariesArray<Types::TrafficPolicySummary>

A list that contains one TrafficPolicySummary element for each traffic policy that was created by the current Amazon Web Services account.

Returns:



5584
5585
5586
5587
5588
5589
5590
5591
# File 'lib/aws-sdk-route53/types.rb', line 5584

class ListTrafficPoliciesResponse < Struct.new(
  :traffic_policy_summaries,
  :is_truncated,
  :traffic_policy_id_marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end