Class: Aws::Route53::Types::ListTrafficPolicyInstancesByHostedZoneRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListTrafficPolicyInstancesByHostedZoneRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A request for the traffic policy instances that you created in a specified hosted zone.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hosted_zone_id ⇒ String
The ID of the hosted zone that you want to list traffic policy instances for.
-
#max_items ⇒ Integer
The maximum number of traffic policy instances to be included in the response body for this request.
-
#traffic_policy_instance_name_marker ⇒ String
If the value of
IsTruncatedin the previous response is true, you have more traffic policy instances. -
#traffic_policy_instance_type_marker ⇒ String
If the value of
IsTruncatedin the previous response is true, you have more traffic policy instances.
Instance Attribute Details
#hosted_zone_id ⇒ String
The ID of the hosted zone that you want to list traffic policy instances for.
5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-route53/types.rb', line 5640 class ListTrafficPolicyInstancesByHostedZoneRequest < Struct.new( :hosted_zone_id, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of traffic policy instances to be included in the
response body for this request. If you have more than MaxItems
traffic policy instances, the value of the IsTruncated element in
the response is true, and the values of HostedZoneIdMarker,
TrafficPolicyInstanceNameMarker, and
TrafficPolicyInstanceTypeMarker represent the first traffic policy
instance that Amazon Route 53 will return if you submit another
request.
5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-route53/types.rb', line 5640 class ListTrafficPolicyInstancesByHostedZoneRequest < Struct.new( :hosted_zone_id, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_instance_name_marker ⇒ String
If the value of IsTruncated in the previous response is true, you
have more traffic policy instances. To get more traffic policy
instances, submit another ListTrafficPolicyInstances request. For
the value of trafficpolicyinstancename, specify the value of
TrafficPolicyInstanceNameMarker from the previous response, which
is the name of the first traffic policy instance in the next group
of traffic policy instances.
If the value of IsTruncated in the previous response was false,
there are no more traffic policy instances to get.
5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-route53/types.rb', line 5640 class ListTrafficPolicyInstancesByHostedZoneRequest < Struct.new( :hosted_zone_id, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_instance_type_marker ⇒ String
If the value of IsTruncated in the previous response is true, you
have more traffic policy instances. To get more traffic policy
instances, submit another ListTrafficPolicyInstances request. For
the value of trafficpolicyinstancetype, specify the value of
TrafficPolicyInstanceTypeMarker from the previous response, which
is the type of the first traffic policy instance in the next group
of traffic policy instances.
If the value of IsTruncated in the previous response was false,
there are no more traffic policy instances to get.
5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-route53/types.rb', line 5640 class ListTrafficPolicyInstancesByHostedZoneRequest < Struct.new( :hosted_zone_id, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :max_items) SENSITIVE = [] include Aws::Structure end |