Class: Aws::Route53::Types::ListTrafficPolicyInstancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListTrafficPolicyInstancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A complex type that contains the response information for the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hosted_zone_id_marker ⇒ String
If
IsTruncatedistrue,HostedZoneIdMarkeris the ID of the hosted zone of the first traffic policy instance that Route 53 will return if you submit anotherListTrafficPolicyInstancesrequest. -
#is_truncated ⇒ Boolean
A flag that indicates whether there are more traffic policy instances to be listed.
-
#max_items ⇒ Integer
The value that you specified for the
MaxItemsparameter in the call toListTrafficPolicyInstancesthat produced the current response. -
#traffic_policy_instance_name_marker ⇒ String
If
IsTruncatedistrue,TrafficPolicyInstanceNameMarkeris the name of the first traffic policy instance that Route 53 will return if you submit anotherListTrafficPolicyInstancesrequest. -
#traffic_policy_instance_type_marker ⇒ String
If
IsTruncatedistrue,TrafficPolicyInstanceTypeMarkeris the DNS type of the resource record sets that are associated with the first traffic policy instance that Amazon Route 53 will return if you submit anotherListTrafficPolicyInstancesrequest. -
#traffic_policy_instances ⇒ Array<Types::TrafficPolicyInstance>
A list that contains one
TrafficPolicyInstanceelement for each traffic policy instance that matches the elements in the request.
Instance Attribute Details
#hosted_zone_id_marker ⇒ String
If IsTruncated is true, HostedZoneIdMarker is the ID of the
hosted zone of the first traffic policy instance that Route 53 will
return if you submit another ListTrafficPolicyInstances request.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more traffic policy
instances to be listed. If the response was truncated, you can get
more traffic policy instances by calling
ListTrafficPolicyInstances again and specifying the values of the
HostedZoneIdMarker, TrafficPolicyInstanceNameMarker, and
TrafficPolicyInstanceTypeMarker in the corresponding request
parameters.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The value that you specified for the MaxItems parameter in the
call to ListTrafficPolicyInstances that produced the current
response.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_instance_name_marker ⇒ String
If IsTruncated is true, TrafficPolicyInstanceNameMarker is the
name of the first traffic policy instance that Route 53 will return
if you submit another ListTrafficPolicyInstances request.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_instance_type_marker ⇒ String
If IsTruncated is true, TrafficPolicyInstanceTypeMarker is the
DNS type of the resource record sets that are associated with the
first traffic policy instance that Amazon Route 53 will return if
you submit another ListTrafficPolicyInstances request.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_instances ⇒ Array<Types::TrafficPolicyInstance>
A list that contains one TrafficPolicyInstance element for each
traffic policy instance that matches the elements in the request.
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 |
# File 'lib/aws-sdk-route53/types.rb', line 5943 class ListTrafficPolicyInstancesResponse < Struct.new( :traffic_policy_instances, :hosted_zone_id_marker, :traffic_policy_instance_name_marker, :traffic_policy_instance_type_marker, :is_truncated, :max_items) SENSITIVE = [] include Aws::Structure end |