Class: Aws::Route53::Types::TooManyTrafficPolicyVersionsForCurrentPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53/types.rb

Overview

This traffic policy version can't be created because you've reached the limit of 1000 on the number of versions that you can create for the current traffic policy.

To create more traffic policy versions, you can use GetTrafficPolicy to get the traffic policy document for a specified traffic policy version, and then use CreateTrafficPolicy to create a new traffic policy using the traffic policy document.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


7369
7370
7371
7372
7373
# File 'lib/aws-sdk-route53/types.rb', line 7369

class TooManyTrafficPolicyVersionsForCurrentPolicy < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end