Class: Aws::Route53::Types::ListTrafficPoliciesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53::Types::ListTrafficPoliciesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53/types.rb
Overview
A complex type that contains the response information for the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more traffic policies to be listed.
-
#max_items ⇒ Integer
The value that you specified for the
MaxItemsparameter in theListTrafficPoliciesrequest that produced the current response. -
#traffic_policy_id_marker ⇒ String
If the value of
IsTruncatedistrue,TrafficPolicyIdMarkeris the ID of the first traffic policy in the next group ofMaxItemstraffic policies. -
#traffic_policy_summaries ⇒ Array<Types::TrafficPolicySummary>
A list that contains one
TrafficPolicySummaryelement for each traffic policy that was created by the current Amazon Web Services account.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more traffic policies to be
listed. If the response was truncated, you can get the next group of
traffic policies by submitting another ListTrafficPolicies request
and specifying the value of TrafficPolicyIdMarker in the
TrafficPolicyIdMarker request parameter.
5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-route53/types.rb', line 5584 class ListTrafficPoliciesResponse < Struct.new( :traffic_policy_summaries, :is_truncated, :traffic_policy_id_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The value that you specified for the MaxItems parameter in the
ListTrafficPolicies request that produced the current response.
5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-route53/types.rb', line 5584 class ListTrafficPoliciesResponse < Struct.new( :traffic_policy_summaries, :is_truncated, :traffic_policy_id_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_id_marker ⇒ String
If the value of IsTruncated is true, TrafficPolicyIdMarker is
the ID of the first traffic policy in the next group of MaxItems
traffic policies.
5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-route53/types.rb', line 5584 class ListTrafficPoliciesResponse < Struct.new( :traffic_policy_summaries, :is_truncated, :traffic_policy_id_marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#traffic_policy_summaries ⇒ Array<Types::TrafficPolicySummary>
A list that contains one TrafficPolicySummary element for each
traffic policy that was created by the current Amazon Web Services
account.
5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/aws-sdk-route53/types.rb', line 5584 class ListTrafficPoliciesResponse < Struct.new( :traffic_policy_summaries, :is_truncated, :traffic_policy_id_marker, :max_items) SENSITIVE = [] include Aws::Structure end |